Citation
==========

How to cite Uxarray
-----------------------

Cite Uxarray using the following text:

**UXARRAY Organization. (Year).
Uxarray (version \<version\>) [Software].
Project Raijin & Project SEATS. doi:10.5281/zenodo.<doi-part-per-version>.**

Update the year, Uxarray version, and DOI part for UXarray version as appropriate. For example:

**UXARRAY Organization. (2021).
Uxarray (version 0.0.2) [Software].
Project Raijin & Project SEATS. doi:10.5281/zenodo.5658256.**
